@@ -4,17 +4,18 @@ items <- data.frame(ID = paste0("item_", 1:10),
                     itemValues = c(-4, -4, -2, -2, -1, -1, 20, 20, 0, 0),
                     stringsAsFactors = FALSE)
 
-usage <- itemUsageConstraint(nForms = 2, nItems = 10, operator = "=", targetValue = 1)
-perForm <- itemsPerFormConstraint(nForms = 2, nItems = 10, operator = "=", targetValue = 5)
-target <- itemTargetConstraint(nForms = 2, nItems = 10,
-                               itemValues = items$itemValues,
-                               targetValue = 0)
+usage <- itemUsageConstraint(nForms = 2, nItems = 10, operator = "=",
+                             targetValue = 1, itemIDs = items$ID)
+perForm <- itemsPerFormConstraint(nForms = 2, nItems = 10, operator = "=",
+                                  targetValue = 5, itemIDs = items$ID)
+target <- minimaxConstraint(nForms = 2, itemValues = items$itemValues,
+                               targetValue = 0, itemIDs = items$ID)
 
 suppressMessages(sol <- useSolver(allConstraints = list(usage, perForm, target),
-                 nForms = 2, itemIDs = items$ID, solver = "lpSolve"))
+                 solver = "lpSolve", formNames = "block"))
 
 suppressMessages(sol_empty <- useSolver(allConstraints = list(target),
-                                  nForms = 2, itemIDs = items$ID, solver = "lpSolve"))
+                                  solver = "lpSolve"))
 
 
 test_that("append solution", {
@@ -22,7 +23,14 @@ test_that("append solution", {
 
   expect_equal(dim(out), c(10, 4))
   expect_equal(names(out), c(names(items), paste0("block_", 1:2)))
-  expect_equal(rownames(out), paste0("item_", 1:10))
+  expect_equal(out$ID, paste0("item_", 1:10))
+  expect_equal(rownames(out), as.character(1:10))
+
+  out <- appendSolution(sol, items = items, idCol = 1)
+
+  expect_equal(dim(out), c(10, 4))
+  expect_equal(names(out), c(names(items), paste0("block_", 1:2)))
+  expect_equal(out$ID, paste0("item_", 1:10))
 })
 
 
